# -*- coding: utf-8 -*-
# Copyright (c) 2019 Dzmitry Maliuzhenets; MIT License
"""The module contains information about the types used.

The module is not intended for execution and should be used only for
informational purposes during development.

Attributes:
    BOT_API_VERSION (float): current Telegram Bot Api version
    ALL_USED_ANNOTATIONS (set): all used annotations
    ALL_TYPES (set): all used types
    ALL_METHODS_RETURNS_TYPES (set): method return types
    METHODS_RETURN_TYPES (dict): method return types
    UNION_ANNOTATIONS_IN_TYPELIB_MODULE (set): union annotation in typelib
    ALL_USED_ANNOTATIONS_IN_TYPES (set): all annotations in  typelib
    UNION_ANNOTATIONS_IN_METHODS (set): union annotation used by Telegram Bot
        Api methods
"""

BOT_API_VERSION = 4.2

ALL_USED_ANNOTATIONS = {'Chat',
                        'ChatMember',
                        'EncryptedCredentials',
                        'File',
                        'InputFile',
                        'InputMedia',
                        'InputMessageContent',
                        'List[ChatMember]',
                        'List[EncryptedPassportElement]',
                        'List[GameHighScore]',
                        'List[InlineQueryResult]',
                        'List[LabeledPrice]',
                        'List[List[InlineKeyboardButton]]',
                        'List[List[KeyboardButton]]',
                        'List[List[PhotoSize]]',
                        'List[PassportElementError]',
                        'List[PhotoSize]',
                        'List[PollOption]',
                        'List[Sticker]',
                        'List[Union[InputMediaPhoto, InputMediaVideo]]',
                        'List[Update]',
                        'List[str]',
                        'Location',
                        'Message',
                        'Optional[Animation]',
                        'Optional[Audio]',
                        'Optional[CallbackGame]',
                        'Optional[CallbackQuery]',
                        'Optional[ChatPhoto]',
                        'Optional[Chat]',
                        'Optional[ChosenInlineResult]',
                        'Optional[Contact]',
                        'Optional[Document]',
                        'Optional[Game]',
                        'Optional[InlineKeyboardMarkup]',
                        'Optional[InlineQuery]',
                        'Optional[InputFile]',
                        'Optional[InputMessageContent]',
                        'Optional[Invoice]',
                        'Optional[List[LabeledPrice]]',
                        'Optional[List[MessageEntity]]',
                        'Optional[List[PassportFile]]',
                        'Optional[List[PhotoSize]]',
                        'Optional[List[User]]',
                        'Optional[List[str]]',
                        'Optional[Location]',
                        'Optional[MaskPosition]',
                        'Optional[Message]',
                        'Optional[OrderInfo]',
                        'Optional[PassportData]',
                        'Optional[PassportFile]',
                        'Optional[PhotoSize]',
                        'Optional[Poll]',
                        'Optional[PreCheckoutQuery]',
                        'Optional[ShippingAddress]',
                        'Optional[ShippingQuery]',
                        'Optional[Sticker]',
                        'Optional[SuccessfulPayment]',
                        ('Optional[Union[InlineKeyboardMarkup, '
                         'ReplyKeyboardMarkup, '),
                        'ReplyKeyboardRemove, ForceReply]]',
                        'Optional[Union[InputFile, str]]',
                        'Optional[Union[int, str]]',
                        'Optional[User]',
                        'Optional[Venue]',
                        'Optional[VideoNote]',
                        'Optional[Video]',
                        'Optional[Voice]',
                        'Optional[bool]',
                        'Optional[int]',
                        'Optional[str]',
                        'Pool',
                        'ShippingAddress',
                        'StickerSet',
                        'Union[InputFile, str]',
                        'Union[Message, bool]',
                        'Union[int, str]',
                        'User',
                        'UserProfilePhotos',
                        'WebhookInfo',
                        'bool',
                        'float',
                        'int',
                        'str'}

ALL_TYPES = {
    'Animation',
    'Audio',
    'Base',
    'CallbackGame',
    'CallbackQuery',
    'Chat',
    'ChatMember',
    'ChatPhoto',
    'ChosenInlineResult',
    'Contact',
    'Document',
    'EncryptedCredentials',
    'EncryptedPassportElement',
    'File',
    'ForceReply',
    'Game',
    'GameHighScore',
    'InlineKeyboardButton',
    'InlineKeyboardMarkup',
    'InlineQuery',
    'InlineQueryResultArticle',
    'InlineQueryResultAudio',
    'InlineQueryResultCachedAudio',
    'InlineQueryResultCachedDocument',
    'InlineQueryResultCachedGif',
    'InlineQueryResultCachedMpeg4Gif',
    'InlineQueryResultCachedPhoto',
    'InlineQueryResultCachedSticker',
    'InlineQueryResultCachedVideo',
    'InlineQueryResultCachedVoice',
    'InlineQueryResultContact',
    'InlineQueryResultDocument',
    'InlineQueryResultGame',
    'InlineQueryResultGif',
    'InlineQueryResultLocation',
    'InlineQueryResultMpeg4Gif',
    'InlineQueryResultPhoto',
    'InlineQueryResultVenue',
    'InlineQueryResultVideo',
    'InlineQueryResultVoice',
    'InputContactMessageContent',
    'InputFile',
    'InputLocationMessageContent',
    'InputMediaAnimation',
    'InputMediaAudio',
    'InputMediaDocument',
    'InputMediaPhoto',
    'InputMediaVideo',
    'InputMessageContent',
    'InputTextMessageContent',
    'InputVenueMessageContent',
    'Invoice',
    'KeyboardButton',
    'LabeledPrice',
    'Location',
    'MaskPosition',
    'Message',
    'MessageEntity',
    'OrderInfo',
    'PassportData',
    'PassportElementErrorDataField',
    'PassportElementErrorFile',
    'PassportElementErrorFiles',
    'PassportElementErrorFrontSide',
    'PassportElementErrorReverseSide',
    'PassportElementErrorSelfie',
    'PassportElementErrorTranslationFile',
    'PassportElementErrorTranslationFiles',
    'PassportElementErrorUnspecified',
    'PassportFile',
    'PhotoSize',
    'Poll',
    'PollOption',
    'PreCheckoutQuery',
    'ReplyKeyboardMarkup',
    'ReplyKeyboardRemove',
    'ResponseParameters',
    'ShippingAddress',
    'ShippingOption',
    'ShippingQuery',
    'Sticker',
    'StickerSet',
    'SuccessfulPayment',
    'Update',
    'User',
    'UserProfilePhotos',
    'Venue',
    'Video',
    'VideoNote',
    'Voice',
    'WebhookInfo'
}

ALL_METHODS_RETURNS_TYPES = {
    'Chat',
    'ChatMember',
    'File',
    'List[ChatMember]',
    'List[GameHighScore]',
    'List[Update]',
    'Message',
    'Pool',
    'StickerSet',
    'Union[Message, bool]',
    'User',
    'UserProfilePhotos',
    'WebhookInfo',
    'bool',
    'int',
    'str'
}
METHODS_RETURN_TYPES = {
    "getMe": "User",
    "sendMessage": "Message",
    "forwardMessage": "Message",
    "sendPhoto": "Message",
    "sendAudio": "Message",
    "sendDocument": "Message",
    "sendVideo": "Message",
    "sendAnimation": "Message",
    "sendVoice": "Message",
    "sendVideoNote": "Message",
    "sendMediaGroup": "Message",
    "sendLocation": "Message",
    "editMessageLiveLocation": "Union[Message, bool]",
    "stopMessageLiveLocation": "Union[Message, bool]",
    "sendVenue": "Message",
    "sendContact": "Message",
    "sendPoll": "Message",
    "sendChatAction": "bool",
    "getUserProfilePhotos": "UserProfilePhotos",
    "getFile": "File",
    "kickChatMember": "bool",
    "unbanChatMember": "bool",
    "restrictChatMember": "bool",
    "promoteChatMember": "bool",
    "exportChatInviteLink": "str",
    "setChatPhoto": "bool",
    "deleteChatPhoto": "bool",
    "setChatTitle": "bool",
    "setChatDescription": "bool",
    "pinChatMessage": "bool",
    "unpinChatMessage": "bool",
    "leaveChat": "bool",
    "getChat": "Chat",
    "getChatAdministrators": "List[ChatMember]",
    "getChatMembersCount": "int",
    "getChatMember": "ChatMember",
    "setChatStickerSet": "bool",
    "deleteChatStickerSet": "bool",
    "answerCallbackQuery": "bool",
    "sendGame": "Message",
    "setGameScore": "Union[Message, bool]",
    "getGameHighScores": "List[GameHighScore]",
    "getUpdates": "List[Update]",
    "setWebhook": "bool",
    "deleteWebhook": "bool",
    "getWebhookInfo": "WebhookInfo",
    "answerInlineQuery": "bool",
    "setPassportDataErrors": "bool",
    "sendInvoice": "Message",
    "answerShippingQuery": "bool",
    "answerPreCheckoutQuery": "bool",
    "sendSticker": "Message",
    "getStickerSet": "StickerSet",
    "uploadStickerFile": "File",
    "createNewStickerSet": "bool",
    "addStickerToSet": "bool",
    "setStickerPositionInSet": "bool",
    "deleteStickerFromSet": "bool",
    "editMessageText": "Union[Message, bool]",
    "editMessageCaption": "Union[Message, bool]",
    "editMessageMedia": "Union[Message, bool]",
    "editMessageReplyMarkup": "Union[Message, bool]",
    "stopPoll": "Poll",
    "deleteMessage": "bool",
}

UNION_ANNOTATIONS_IN_TYPELIB_MODULE = {
    'Optional[Union[InputFile, str]]',
}

ALL_USED_ANNOTATIONS_IN_TYPES = {
    'Chat',
    'EncryptedCredentials',
    'InputMessageContent',
    'List[EncryptedPassportElement]',
    'List[LabeledPrice]',
    'List[List[InlineKeyboardButton]]',
    'List[List[KeyboardButton]]',
    'List[List[PhotoSize]]',
    'List[PhotoSize]',
    'List[PollOption]',
    'List[Sticker]',
    'List[str]',
    'Location',
    'Optional[Animation]',
    'Optional[Audio]',
    'Optional[CallbackGame]',
    'Optional[CallbackQuery]',
    'Optional[ChatPhoto]',
    'Optional[Chat]',
    'Optional[ChosenInlineResult]',
    'Optional[Contact]',
    'Optional[Document]',
    'Optional[Game]',
    'Optional[InlineKeyboardMarkup]',
    'Optional[InlineQuery]',
    'Optional[InputMessageContent]',
    'Optional[Invoice]',
    'Optional[List[MessageEntity]]',
    'Optional[List[PassportFile]]',
    'Optional[List[PhotoSize]]',
    'Optional[List[User]]',
    'Optional[List[str]]',
    'Optional[Location]',
    'Optional[MaskPosition]',
    'Optional[Message]',
    'Optional[OrderInfo]',
    'Optional[PassportData]',
    'Optional[PassportFile]',
    'Optional[PhotoSize]',
    'Optional[Poll]',
    'Optional[PreCheckoutQuery]',
    'Optional[ShippingAddress]',
    'Optional[ShippingQuery]',
    'Optional[Sticker]',
    'Optional[SuccessfulPayment]',
    'Optional[Union[InputFile, str]]',
    'Optional[User]',
    'Optional[Venue]',
    'Optional[VideoNote]',
    'Optional[Video]',
    'Optional[Voice]',
    'Optional[bool]',
    'Optional[int]',
    'Optional[str]',
    'ShippingAddress',
    'User',
    'bool',
    'float',
    'int',
    'str',

}
UNION_ANNOTATIONS_IN_METHODS = {
    'List[Union[InputMediaPhoto, InputMediaVideo]]',
    'Optional[Union[InlineKeyboardMarkup, ReplyKeyboardMarkup, ReplyKeyboardRemove, ForceReply]]',
    'Optional[Union[InputFile, str]]',
    'Optional[Union[int, str]]',
    'Union[InputFile, str]',
    'Union[int, str]',
}
